@@ -13,7 +13,7 @@ parts of the model, or different models.
 #__all__ = [ 'Parameter']
 import operator
 import sys
-from six.moves import reduce
+from functools import reduce
 import warnings
 from copy import copy
 import math
@@ -1136,4 +1136,4 @@ def test_operator():
     a_b = a + b
     a.value = 3
     assert a_b.value == 5.
-    assert a_b.name == '(a + b)'
\ No newline at end of file
+    assert a_b.name == '(a + b)'
