@@ -12,7 +12,7 @@ References::
     (Same title as above, but as a technical report.)
     http://www.icsi.berkeley.edu/~storn/deshort1.ps
 """
-from six.moves import reduce
+from functools import reduce
 
 from math import cos, sqrt
 
@@ -31,4 +31,4 @@ def griewangk(coeffs):
     term2 = prod([cos(xi/sqrt(i+1.)) for i,xi in enumerate(x)])
     return term1 - term2 + 1
 
-prod = lambda x: reduce(lambda a,b: a*b, x, 1.)
\ No newline at end of file
+prod = lambda x: reduce(lambda a,b: a*b, x, 1.)
